@@ -53,6 +53,7 @@ from trackme_libs import (
     trackme_reqinfo,
     trackme_send_to_tcm,
     run_splunk_search,
+    trackme_verify_report_available,
 )
 
 # import trackme libs utils
@@ -943,8 +944,44 @@ class TrackMeHandlerSplkWlkAdmin_v2(trackme_rest_handler.RESTHandler):
                     logger.error(json.dumps(burn_test_results_record, indent=2))
                     return {"payload": burn_test_results_record, "status": 200}
 
-                # sleep
-                time.sleep(5)
+                # Verify the report is available before executing
+                # In large SHC environments, knowledge objects may take time to propagate
+                logger.info(
+                    f'tenant_id="{tenant_id}", burn test report created, verifying availability before execution, report_name="{burn_test_report}"'
+                )
+                
+                report_available = trackme_verify_report_available(
+                    request_info.system_authtoken,
+                    request_info.server_rest_uri,
+                    tenant_id,
+                    burn_test_report,
+                    max_attempts=12,
+                    sleep_time=5,
+                )
+                
+                if not report_available:
+                    # return failure if report is not available after verification attempts
+                    burn_test_results_record = {
+                        "tenant_id": tenant_id,
+                        "report": burn_test_report,
+                        "burn_test_success": False,
+                        "message": "burn test report was created but is not yet available for execution after verification attempts, this may indicate a propagation delay in large SHC environments",
+                        "exception": f'report verification failed, report_name="{burn_test_report}"',
+                    }
+                    
+                    # attempt to remove the report
+                    try:
+                        service.saved_searches.delete(str(burn_test_report))
+                        logger.info(
+                            f'tenant_id="{tenant_id}", burn test, report="{burn_test_report}", action="success", the report was successfully removed after verification failure.'
+                        )
+                    except Exception as e:
+                        logger.error(
+                            f'tenant_id="{tenant_id}", burn test, report="{burn_test_report}", failed to remove the report after verification failure, exception="{str(e)}"'
+                        )
+                    
+                    logger.error(json.dumps(burn_test_results_record, indent=2))
+                    return {"payload": burn_test_results_record, "status": 200}
 
                 logger.info(
                     f'tenant_id="{tenant_id}", burn test was requested, starting abstract report burn test now'
